diff --git a/README.md b/README.md
index b3a060b1e7f2921449319df374ab61b83a1048ab..f4417e5c01f1195414d566eb5634684ca02a5c0a 100644
--- a/README.md
+++ b/README.md
@@ -147,7 +147,7 @@ and the script [dumux/bin/installexternal.py](https://git.iws.uni-stuttgart.de/d
 
 A weekly coverage report of the test suite is created by gcovr/gcov. The report
 currently doesn't include non-instantiated code, so the real coverage is likely lower. However,
-only a few lines of code are never instatiated in the comprehensive test suite.
+only a few lines of code are never instantiated in the comprehensive test suite.
 
 
 # Contributing
diff --git a/bin/extract_as_new_module.py b/bin/extract_as_new_module.py
index 29ac27729cf2d2cc6c2c00211787e3ccca4298a9..30cb4b708de566ddb14c4cf046f719a80bfe67a1 100755
--- a/bin/extract_as_new_module.py
+++ b/bin/extract_as_new_module.py
@@ -509,7 +509,7 @@ def infoInitial(moduleDirectory, subFolder, sourceFiles):
         {1}
 
         and all headers contained in '{0}'
-        that are required to build the exectutables from the sources:
+        that are required to build the executables from the sources:
         {2}
 
         The extracted files are copied into a new DUNE module retaining the directory
diff --git a/bin/util/moduleinfo.py b/bin/util/moduleinfo.py
index 08cc66161ed8ff5519723ddea9425b054fda163c..67b7160f672a901d995f4ec886f5a4818a460480 100644
--- a/bin/util/moduleinfo.py
+++ b/bin/util/moduleinfo.py
@@ -84,7 +84,7 @@ def getDependencies(modulePath, verbose=False, includeSelf=False):
         except RuntimeError:
             if verbose:
                 print(
-                    f" --- skipping folder '{path}' " "as it could not be identifed as dune module"
+                    f" --- skipping folder '{path}' " "as it could not be identified as dune module"
                 )
         else:
             if verbose:
diff --git a/doc/doxygen/pages/external-libs.md b/doc/doxygen/pages/external-libs.md
index 50b021eb2666832eeec51fce0904cb87c8375bbf..fa0fe89663a7292cbd9595eea3ee224725f2d3c4 100644
--- a/doc/doxygen/pages/external-libs.md
+++ b/doc/doxygen/pages/external-libs.md
@@ -40,7 +40,7 @@ Download: https://gitlab.dune-project.org/extensions/dune-spgrid.git
 
 ## Parallel computing (shared memory)
 
-If one of the following libararies is installation, multi-threaded code is enabled in DuMux:
+If one of the following libraries is installation, multi-threaded code is enabled in DuMux:
 
 * `OpenMP`: OpenMP usually comes with the compiler
 * `OneTBB`: TBB, see https://github.com/oneapi-src/oneTBB
diff --git a/doc/doxygen/pages/input-output.md b/doc/doxygen/pages/input-output.md
index 639679b156f42792044cf155b50cb658fe8803c3..ef7c7445eb8efb0184976e0de275a007b745b481 100644
--- a/doc/doxygen/pages/input-output.md
+++ b/doc/doxygen/pages/input-output.md
@@ -57,7 +57,7 @@ Furthermore, petrophysical properties can be defined (for each cell),
 by using eclipse-specific keywords, e.g. `PORO`, `PERMX`, `PERMY`.
 
 DuMux supports the Eclipse Grid Format by using the [`opm-grid` module](https://github.com/OPM/opm-grid)
-of the [Open Porous Media iniative (OPM)](https://opm-project.org).
+of the [Open Porous Media initiave (OPM)](https://opm-project.org).
 See @ref external-libraries for how to install `opm-grid` together with DuMux.
 An example using a corner-point grid can be found in `dumux/test/porousmediumflow/2p/cornerpoint`.
 
diff --git a/doc/doxygen/pages/parameters.md b/doc/doxygen/pages/parameters.md
index 0c5d939f3b242ea01396bb8667aab863964b20c8..45854e3bc173959e7827cf6e2368b1773875ae40 100644
--- a/doc/doxygen/pages/parameters.md
+++ b/doc/doxygen/pages/parameters.md
@@ -150,7 +150,7 @@ Name = test_ff
 ## Command-line arguments
 
 All parameter that can be specified via the parameter file can also
-be overwritten via the command line using the following examplary form:
+be overwritten via the command line using the following exemplary form:
 ```sh
 ./executable params.input -Key Value -Key2 Value2 -Key3 "a b c"
 ```
diff --git a/dumux/adaptive/griddatatransfer.hh b/dumux/adaptive/griddatatransfer.hh
index fecb786484493acd23aa371e8dd4eb7718f913ab..b68f4c603f955c1ab88a02a56de4b31b952aa205 100644
--- a/dumux/adaptive/griddatatransfer.hh
+++ b/dumux/adaptive/griddatatransfer.hh
@@ -7,7 +7,7 @@
 /*!
  * \file
  * \ingroup Adaptive
- * \brief Interface to be used by classes transferring grid data on adpative grids
+ * \brief Interface to be used by classes transferring grid data on adaptive grids
  */
 #ifndef DUMUX_ADAPTIVE_GRIDDATATRANSFER_HH
 #define DUMUX_ADAPTIVE_GRIDDATATRANSFER_HH
@@ -16,7 +16,7 @@ namespace Dumux {
 
 /*!
  * \ingroup Adaptive
- * \brief Interface to be used by classes transferring grid data on adpative grids
+ * \brief Interface to be used by classes transferring grid data on adaptive grids
  */
 template<class Grid>
 class GridDataTransfer
diff --git a/dumux/assembly/partialreassembler.hh b/dumux/assembly/partialreassembler.hh
index ac865866942e010362e45e49775c099beddd14a2..d60d6c16d52d03f917f7fca93e2f03767452dcec 100644
--- a/dumux/assembly/partialreassembler.hh
+++ b/dumux/assembly/partialreassembler.hh
@@ -259,7 +259,7 @@ public:
         // loop over all dofs
         for (unsigned int rowIdx = 0; rowIdx < jacobian.N(); ++rowIdx)
         {
-            // reset all entries corrosponding to a non-green vertex
+            // reset all entries corresponding to a non-green vertex
             if (vertexColor_[rowIdx] != EntityColor::green)
             {
                 // set all matrix entries in the row to 0
diff --git a/dumux/common/math.hh b/dumux/common/math.hh
index 59d7520f7dde43d92f3d45cd97f6e0470ffa93f2..d4d4471859b11f21ad606d2ba919209261e16d63 100644
--- a/dumux/common/math.hh
+++ b/dumux/common/math.hh
@@ -471,7 +471,7 @@ bool isSmaller(const Dune::FieldVector<Scalar, dim> &pos,
  * Compares an current position vector with two reference vector, and returns true
  * if the position vector lies in between them.
  * "Between" in this case means that all the entries of each spatial dimension are
- * smaller in comparison with the larger reference vector as well as larger campared
+ * smaller in comparison with the larger reference vector as well as larger compared
  * to the smaller reference.
  * This is comfortable to cheack weather the current position is located inside or
  * outside of a lense with different properties.
diff --git a/dumux/common/properties.hh b/dumux/common/properties.hh
index f726c7c8fc99f1d3d01b8829f0f3643bddbbc879..8c198ad3b91b8d8b62d5beaddf9b752deb6b3541 100644
--- a/dumux/common/properties.hh
+++ b/dumux/common/properties.hh
@@ -114,7 +114,7 @@ DUMUX_DEFINE_PROPERTY(EnableBoxInterfaceSolver)
 //////////////////////////////////////////////////////////////
 // Additional properties used by the 2pnc and 2pncmin models:
 //////////////////////////////////////////////////////////////
-DUMUX_DEFINE_PROPERTY(Chemistry)                      //!< The chemistry class with which solves equlibrium reactions
+DUMUX_DEFINE_PROPERTY(Chemistry)                      //!< The chemistry class with which equilibrium reactions are solved
 DUMUX_DEFINE_PROPERTY(SetMoleFractionsForFirstPhase)  //!< Set the mole fraction in the wetting or nonwetting phase
 //////////////////////////////////////////////////////////////
 // Additional properties used by the 3pwateroil model:
diff --git a/dumux/common/spline.hh b/dumux/common/spline.hh
index 37915427bc754a21014cc0541196870a2100ac21..a4fcda71dd0101b01d43bf65c86bf284fd66eff8 100644
--- a/dumux/common/spline.hh
+++ b/dumux/common/spline.hh
@@ -45,7 +45,7 @@ public:
     /*!
      * \brief Default constructor for a spline.
      *
-     * To specfiy the actual curve, use one of the set() methods.
+     * To specify the actual curve, use one of the set() methods.
      */
     Spline()
     { };
@@ -127,7 +127,7 @@ public:
     /*!
      * \brief Default constructor for a spline.
      *
-     * To specfiy the actual curve, use one of the set() methods.
+     * To specify the actual curve, use one of the set() methods.
      */
     Spline()
     { }
diff --git a/dumux/discretization/staggered/freeflow/staggeredgeometryhelper.hh b/dumux/discretization/staggered/freeflow/staggeredgeometryhelper.hh
index 1ba6ab95ef18e15fba501ab0299a0fc464325a9f..dfb93d627dfbf1f21ffeabc39f9fbf748416ac4c 100644
--- a/dumux/discretization/staggered/freeflow/staggeredgeometryhelper.hh
+++ b/dumux/discretization/staggered/freeflow/staggeredgeometryhelper.hh
@@ -115,7 +115,7 @@ struct AxisData<GridView, 1>
 
 /*!
  * \ingroup StaggeredDiscretization
- * \brief Returns the dirction index of the facet (0 = x, 1 = y, 2 = z)
+ * \brief Returns the direction index of the facet (0 = x, 1 = y, 2 = z)
  */
 template<class Vector>
 inline static unsigned int directionIndex(Vector&& vector)
diff --git a/dumux/discretization/staggered/freeflow/subcontrolvolumeface.hh b/dumux/discretization/staggered/freeflow/subcontrolvolumeface.hh
index 54d558a9f2ecd18d1b8061e33baadb2e3c5063a1..5caf10a4e67d368336885a8be6f793abcd08d954 100644
--- a/dumux/discretization/staggered/freeflow/subcontrolvolumeface.hh
+++ b/dumux/discretization/staggered/freeflow/subcontrolvolumeface.hh
@@ -235,7 +235,7 @@ public:
         return localFaceIdx_;
     }
 
-    //! Returns the dirction index of the facet (0 = x, 1 = y, 2 = z)
+    //! Returns the direction index of the facet (0 = x, 1 = y, 2 = z)
     unsigned int directionIndex() const
     {
         return dirIdx_;
diff --git a/dumux/freeflow/shallowwater/indices.hh b/dumux/freeflow/shallowwater/indices.hh
index f3e2670112edfcab28e09aee300627040112c7d6..54acaaccec97b8a08cd2e641a5ac551857729f08 100644
--- a/dumux/freeflow/shallowwater/indices.hh
+++ b/dumux/freeflow/shallowwater/indices.hh
@@ -31,7 +31,7 @@ struct ShallowWaterIndices
     static constexpr int waterdepthIdx = massBalanceIdx; //!< Index of the velocity in a solution vector
     static constexpr int velocityXIdx = momentumXBalanceIdx; //!< Index of the velocity in a solution vector
     static constexpr int velocityYIdx = momentumYBalanceIdx; //!< Index of the velocity in a solution vector
-    static constexpr int velocityOffset = velocityXIdx; //!< Offset vor the velocity index
+    static constexpr int velocityOffset = velocityXIdx; //!< Offset for the velocity index
 };
 
 // \}
diff --git a/dumux/io/gnuplotinterface.hh b/dumux/io/gnuplotinterface.hh
index 35607303b23826c1df1191e7c37d1de3ae1266d0..f366e2f1dce4e5e3bc1203b70e98eaf184335135 100644
--- a/dumux/io/gnuplotinterface.hh
+++ b/dumux/io/gnuplotinterface.hh
@@ -346,7 +346,7 @@ public:
     }
 
     /*!
-     * \brief Sets the terminal used for interactive outpu
+     * \brief Sets the terminal used for interactive output
      *
      * \param terminal The user-specified terminal
      */
diff --git a/dumux/io/grid/gridmanager_alu.hh b/dumux/io/grid/gridmanager_alu.hh
index a8b024e31c3d3bf4ab579cd6f89aec4694b509dd..fe799f2c3d797a02ff24674d88d371310ad04f0f 100644
--- a/dumux/io/grid/gridmanager_alu.hh
+++ b/dumux/io/grid/gridmanager_alu.hh
@@ -60,11 +60,11 @@ public:
     void init(const std::string& modelParamGroup = "", bool adaptiveRestart = false)
     {
         // restarting an adaptive grid using Dune's BackupRestoreFacility
-        // TODO: the part after first || is backward compatibility with old sequential models remove once sequential adpative restart is replaced
+        // TODO: the part after first || is backward compatibility with old sequential models remove once sequential adaptive restart is replaced
         if (adaptiveRestart || hasParam("Restart") || hasParam("TimeManager.Restart"))
         {
             auto restartTime = getParamFromGroup<double>(modelParamGroup, "TimeLoop.Restart", 0.0);
-            // TODO: backward compatibility with old sequential models remove once sequential adpative restart is replaced
+            // TODO: backward compatibility with old sequential models remove once sequential adaptive restart is replaced
             if (hasParam("Restart") || hasParam("TimeManager.Restart"))
             {
                 restartTime = getParamFromGroup<double>("TimeManager", "Restart");
@@ -143,7 +143,7 @@ public:
             if (domainMarkers)
                 ParentType::enableGmshDomainMarkers_ = true;
 
-            // only filll the factory for rank 0
+            // only fill the factory for rank 0
             if (domainMarkers)
             {
                 std::vector<int> boundaryMarkersInsertionIndex, boundaryMarkers, faceMarkers, elementMarkers;
diff --git a/dumux/io/grid/porenetwork/gridmanager.hh b/dumux/io/grid/porenetwork/gridmanager.hh
index f4546310eb82f1567ab927deb8b67741b35867d5..5fa822286b17c5fc05af9b0ad163ebdfcd4394f9 100644
--- a/dumux/io/grid/porenetwork/gridmanager.hh
+++ b/dumux/io/grid/porenetwork/gridmanager.hh
@@ -200,7 +200,7 @@ public:
 
         if (std::none_of(keepElement.begin(), keepElement.end(), [](const bool i){return i;}))
             DUNE_THROW(Dune::InvalidStateException, "sanitize() deleted all elements! Check your boundary face indices. "
-                << "If the problem persisits, add at least one of your boundary face indices to PruningSeedIndices");
+                << "If the problem persists, add at least one of your boundary face indices to PruningSeedIndices");
 
         // remove the elements in the grid
         std::size_t numDeletedElements = 0;
diff --git a/dumux/io/json/json.hpp b/dumux/io/json/json.hpp
index 85f16dbe814a5eb5d677998a742670c41f8b2c7d..42bdc6255ecbb807f3f4170a93b1acb9744ed93e 100644
--- a/dumux/io/json/json.hpp
+++ b/dumux/io/json/json.hpp
@@ -5000,7 +5000,7 @@ struct wide_string_input_helper<BaseInputAdapter, 2>
     }
 };
 
-// Wraps another input apdater to convert wide character types into individual bytes.
+// Wraps another input adapter to convert wide character types into individual bytes.
 template<typename BaseInputAdapter, typename WideCharType>
 class wide_string_input_adapter
 {
diff --git a/dumux/material/fluidsystems/brine.hh b/dumux/material/fluidsystems/brine.hh
index 87dc9e02a7fc8d3b6d822515f89f79a615507e5a..dc62a3768fb526ac3c7a9d2d221c5f8d57b00a95 100644
--- a/dumux/material/fluidsystems/brine.hh
+++ b/dumux/material/fluidsystems/brine.hh
@@ -396,7 +396,7 @@ public:
      * The implemented value for NaCl is for a molar concentration of 2.5984 mol/l and a temperature of 25°C,
      * see Rard and Miller, 1979 (DOI: 10.1007/BF00648776) \cite Rard1979.
      * Dependent on the salt concentration the coefficient can vary between 1.47e-9 m^2/s and 1.6e-9 m^2/s, see Rard and Miller, 1979.
-     * It also depends on temperature; values for different temparatures can e.g. found here: Alanis et al., 2000 (DOI: 10.1117/1.602422) \cite Alanis2000.
+     * It also depends on temperature; values for different temperatures can e.g. found here: Alanis et al., 2000 (DOI: 10.1117/1.602422) \cite Alanis2000.
      */
     template <class FluidState>
     static Scalar binaryDiffusionCoefficient(const FluidState& fluidState,
diff --git a/dumux/multidomain/couplingmanager.hh b/dumux/multidomain/couplingmanager.hh
index e1cc22ac51f1032fea58007086d2bcdc97956814..d995e46327c0fd581979e593536867a546dce8ad 100644
--- a/dumux/multidomain/couplingmanager.hh
+++ b/dumux/multidomain/couplingmanager.hh
@@ -200,7 +200,7 @@ public:
      *
      * \note Such variables do not necessarily exist and then this function does nothing (default)
      * \note some examples
-     *       from geomechanics: the porosity of (physical) domain i (porous medium flow) depends on the displacement vector of physical domain j (mechnanics)
+     *       from geomechanics: the porosity of (physical) domain i (porous medium flow) depends on the displacement vector of physical domain j (mechanics)
      *       from domaindecomposition: the transmissibilities for fluxes of domain i to domain j depend on the permeability in domain j
      *                                 (which might depend in turn on the primary variables of domain i)
      */
diff --git a/dumux/porenetwork/common/throatproperties.hh b/dumux/porenetwork/common/throatproperties.hh
index 61b4eb6cc1982267d6f003407eb658b7141cfb28..fc669b81b66595d24e312cac9fa9f34d150c2bd1 100644
--- a/dumux/porenetwork/common/throatproperties.hh
+++ b/dumux/porenetwork/common/throatproperties.hh
@@ -138,7 +138,7 @@ inline constexpr Scalar shapeFactorRectangle(const Scalar inscribedRadius, const
     return area / (perimeter*perimeter);
 }
 
-//! Returns the value of the shape factor for a cicle
+//! Returns the value of the shape factor for a circle
 template<class Scalar>
 inline constexpr Scalar shapeFactorCircle() noexcept
 {
diff --git a/dumux/porousmediumflow/fluxvariablescache.hh b/dumux/porousmediumflow/fluxvariablescache.hh
index a53e879413509fe45165326509bb360300b84465..1594321540b4cd471d6bba16898c02dcc9f374ea 100644
--- a/dumux/porousmediumflow/fluxvariablescache.hh
+++ b/dumux/porousmediumflow/fluxvariablescache.hh
@@ -52,7 +52,7 @@ public:
 };
 
 // the following classes choose the cache type: empty if the law disabled and the law's cache if it's enabled
-// if advections is disabled the advection type is still instatiated if we use std::conditional_t and has to be a full type
+// if advections is disabled the advection type is still instantiated if we use std::conditional_t and has to be a full type
 // in order to prevent that instead of std::conditional_t we use this helper type is only dependent on the advection type
 // if advection is enabled otherwise its an empty cache type
 template<class TypeTag, bool EnableAdvection> class AdvectionCacheChooser : public FluxVariablesCaching::EmptyAdvectionCache {};
diff --git a/dumux/porousmediumflow/richards/localresidual.hh b/dumux/porousmediumflow/richards/localresidual.hh
index 07f386e7d8163fd93b98e9f78ed5a71849ddaa9f..f52fd97e1a5699a66ec86476414cc235abc14034 100644
--- a/dumux/porousmediumflow/richards/localresidual.hh
+++ b/dumux/porousmediumflow/richards/localresidual.hh
@@ -367,7 +367,7 @@ public:
         const auto upwindContributionInside = rho_mu*flux*insideWeight*dkrw_dsw_inside*dsw_dpw_inside;
         const auto upwindContributionOutside = rho_mu*flux*outsideWeight*dkrw_dsw_outside*dsw_dpw_outside;
 
-        // additional constribution of the upwind term only for inside and outside dof
+        // additional contribution of the upwind term only for inside and outside dof
         A[insideScv.dofIndex()][insideScv.dofIndex()][conti0EqIdx][0] += upwindContributionInside;
         A[insideScv.dofIndex()][outsideScv.dofIndex()][conti0EqIdx][0] += upwindContributionOutside;
 
diff --git a/dumux/porousmediumflow/velocity.hh b/dumux/porousmediumflow/velocity.hh
index 6d8368db9b949f93064fce49a6de817a76b7b254..9625d8e321abf6e59661f658f0621e338ef2e765 100644
--- a/dumux/porousmediumflow/velocity.hh
+++ b/dumux/porousmediumflow/velocity.hh
@@ -142,7 +142,7 @@ public:
                 if (scvf.boundary())
                     continue;
 
-                // insantiate the flux variables
+                // instantiate the flux variables
                 FluxVariables fluxVars;
                 fluxVars.init(problem_, element, fvGeometry, elemVolVars, scvf, elemFluxVarsCache);
 
diff --git a/examples/biomineralization/doc/fluidmaterial.md b/examples/biomineralization/doc/fluidmaterial.md
index 1cf8f0dfce73d37e163ee424b158b55e0cb70e5b..ed6f4938ee79ad1dbfe6b6f7ca6283cd34d20d31 100644
--- a/examples/biomineralization/doc/fluidmaterial.md
+++ b/examples/biomineralization/doc/fluidmaterial.md
@@ -29,7 +29,7 @@ For further specialization, the overview over the material subfolder is split in
 
 ## Fluids in the folder `material`
 
-As this example is about biomineralization involving many components with complex inteactions, some specific fluid material files are necessary.
+As this example is about biomineralization involving many components with complex interactions, some specific fluid material files are necessary.
 This example uses a simplified version of CO<sub>2</sub> mostly based on an ideal gas assumption.
 In the component subfolder, `material/components/suspendedbiomass.hh` defines the component suspended biomass, which is the mobile form of biomass being transported suspended in the aqueous fluid phase.
 In the fluidsystem subfolder, the biomineralization fluidsystem `material/fluidsystems/biominsimplechemistry.hh` as well as
diff --git a/examples/biomineralization/doc/fluidmaterial_intro.md b/examples/biomineralization/doc/fluidmaterial_intro.md
index eb918ee2f4afd85867266d82b79f76d671094783..095065e63a9c479c63f6333ffb193e377301763f 100644
--- a/examples/biomineralization/doc/fluidmaterial_intro.md
+++ b/examples/biomineralization/doc/fluidmaterial_intro.md
@@ -23,7 +23,7 @@ For further specialization, the overview over the material subfolder is split in
 
 ## Fluids in the folder `material`
 
-As this example is about biomineralization involving many components with complex inteactions, some specific fluid material files are necessary.
+As this example is about biomineralization involving many components with complex interactions, some specific fluid material files are necessary.
 This example uses a simplified version of CO<sub>2</sub> mostly based on an ideal gas assumption.
 In the component subfolder, `material/components/suspendedbiomass.hh` defines the component suspended biomass, which is the mobile form of biomass being transported suspended in the aqueous fluid phase.
 In the fluidsystem subfolder, the biomineralization fluidsystem `material/fluidsystems/biominsimplechemistry.hh` as well as
diff --git a/examples/biomineralization/doc/solidmaterial.md b/examples/biomineralization/doc/solidmaterial.md
index 009ccb6d81ee443338be9b8c25f6930c5fd9a2d4..c7682b490c890ec9124c2ee2215616359ca57fb6 100644
--- a/examples/biomineralization/doc/solidmaterial.md
+++ b/examples/biomineralization/doc/solidmaterial.md
@@ -29,7 +29,7 @@ For further specialization, the overview over the material subfolder is split in
 
 ## Solids in the folder `material`
 
-As this example is about biomineralization involving many components with complex inteactions, some specific solid material files are necessary.
+As this example is about biomineralization involving many components with complex interactions, some specific solid material files are necessary.
 First, `material/components/biofilm.hh` defines the solid component biofilm, which plays an essential role in biomineralization by providing the essential catalytic activity for biomineralization.
 Second, as biofilm grows or calcite precipitates, the volume fractions of those non-inert solids change, influencing the overall properties of the solids in the system.
 The specific solidsystem `material/solidsystems/biominsolids.hh` gives the relations on how to
diff --git a/examples/biomineralization/doc/solidmaterial_intro.md b/examples/biomineralization/doc/solidmaterial_intro.md
index 6fc0d7b67093a8384b6bd7faaed209ba8c4d6b00..cc345dd9352fe00a3c766f4bad17700c4aa6be86 100644
--- a/examples/biomineralization/doc/solidmaterial_intro.md
+++ b/examples/biomineralization/doc/solidmaterial_intro.md
@@ -23,7 +23,7 @@ For further specialization, the overview over the material subfolder is split in
 
 ## Solids in the folder `material`
 
-As this example is about biomineralization involving many components with complex inteactions, some specific solid material files are necessary.
+As this example is about biomineralization involving many components with complex interactions, some specific solid material files are necessary.
 First, `material/components/biofilm.hh` defines the solid component biofilm, which plays an essential role in biomineralization by providing the essential catalytic activity for biomineralization.
 Second, as biofilm grows or calcite precipitates, the volume fractions of those non-inert solids change, influencing the overall properties of the solids in the system.
 The specific solidsystem `material/solidsystems/biominsolids.hh` gives the relations on how to
diff --git a/bin/installdumux.py b/bin/installdumux.py
index 5d19e43c2cd2ea4afe59ab68c8448c3c407b8da4..cf6d070667facf9012f52d462ba695b0d1727fa0 100755
--- a/bin/installdumux.py
+++ b/bin/installdumux.py
@@ -84,7 +84,7 @@ def checkCppVersion():
     requiredversion = "9.3"
     result = subprocess.check_output(["g++", "-dumpversion"]).decode().strip()
     if _Version(result) < _Version(requiredversion):
-        logger.error("An error occurred while checking for prerequistes.")
+        logger.error("An error occurred while checking for prerequisites.")
         logger.error(f"g++ greater than or equal to {requiredversion} is required.")
         sys.exit(1)
 
@@ -131,16 +131,16 @@ with open("installdumux.log", "w") as _:
 
 #################################################################
 #################################################################
 # (1/3) Check some prerequistes
 #################################################################
 #################################################################
 programs = ["git", "gcc", "g++", "cmake", "pkg-config"]
-showMessage(f"(1/3) Checking all prerequistes: {' '.join(programs)}...")
+showMessage(f"(1/3) Checking all prerequisites: {' '.join(programs)}...")
 
 # check some prerequistes
 for program in programs:
     if which(program) is None:
-        logger.error("An error occurred while checking for prerequistes.")
+        logger.error("An error occurred while checking for prerequisites.")
         logger.error(f"The required program '{program}' has not been found.")
         sys.exit(1)
 
@@ -150,7 +150,7 @@ if which("paraview") is None:
 
 checkCppVersion()
 
-showMessage("(1/3) Step completed. All prerequistes found.")
+showMessage("(1/3) Step completed. All prerequisites found.")
 
 #################################################################
 #################################################################
@@ -131,16 +131,16 @@ with open("installdumux.log", "w") as _:
 #################################################################
 #################################################################
-# (1/3) Check some prerequistes
+# (1/3) Check some prerequisites
 #################################################################
 #################################################################
@@ -131,16 +131,16 @@ with open("installdumux.log", "w") as _:
 
-# check some prerequistes
+# check some prerequisites
 for program in programs:
     if which(program) is None: